@@ -4,7 +4,7 @@ package Dist::Zilla::App::Command::stale;
 # ABSTRACT: print your distribution's prerequisites and plugins that are out of date
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 use Dist::Zilla::App -command;
 
@@ -109,8 +109,12 @@ sub execute
         require List::MoreUtils;
         $self->log(join("\n", List::MoreUtils::uniq(sort @authordeps)));
 
-        print STDERR "Some authordeps were missing. Run the stale command again to check for regular dependencies.\n"
-            if @authordeps;
+        if (@authordeps)
+        {
+            require Term::ANSIColor;
+            Term::ANSIColor->VERSION('3.00');
+            print STDERR Term::ANSIColor::colored("Some authordeps were missing. Run the stale command again to check for regular dependencies.\n", 'bright_yellow');
+        }
 
         undef;  # ensure $zilla = undef
     };
@@ -158,7 +162,7 @@ Dist::Zilla::App::Command::stale - print your distribution's prerequisites and p
 
 =head1 VERSION
 
-version 0.042
+version 0.043
 
 =head1 SYNOPSIS
 
