@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.041-7-g969c3d9
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.042-8-gb659b36
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.042';
+our $VERSION = '0.043';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -16,6 +16,7 @@ use Moose::Util::TypeConstraints 'enum';
 use List::Util 1.33 qw(none any);
 use List::MoreUtils 'uniq';
 use version;
+use Moose::Util 'find_meta';
 use Path::Tiny;
 use Cwd;
 use CPAN::DistnameInfo;
@@ -115,7 +116,7 @@ sub after_build
     if ($self->phase eq 'build' and $self->check_all_prereqs)
     {
         my @modules = $self->_modules_prereq;
-        $self->_check_modules(@modules) if @modules;
+        $self->_check_modules(uniq @modules) if @modules;
     }
 }
 
@@ -292,7 +293,7 @@ has _modules_plugin => (
         [
             grep { my $module = $_; none { $module eq $_ } @skip }
             uniq
-            map { $_->meta->name } @{ $self->zilla->plugins }
+            map { find_meta($_)->name } @{ $self->zilla->plugins }
         ];
     },
 );
@@ -448,7 +449,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.042
+version 0.043
 
 =head1 SYNOPSIS
 
